Index: tests/OSPathTest.cpp |
diff --git a/tests/OSPathTest.cpp b/tests/OSPathTest.cpp |
index facc6ad3f70a6020a13a171994f1cc595355eddf..3276145fa4012f208aae2ad01d62a98bd2ddc286 100644 |
--- a/tests/OSPathTest.cpp |
+++ b/tests/OSPathTest.cpp |
@@ -86,8 +86,8 @@ DEF_TEST(OSPath, reporter) { |
SkString baseOfDir = SkOSPath::Basename(dir.c_str()); |
REPORTER_ASSERT(reporter, baseOfDir.size() == 0); |
- // Basename of NULL is an empty string. |
- SkString empty = SkOSPath::Basename(NULL); |
+ // Basename of nullptr is an empty string. |
+ SkString empty = SkOSPath::Basename(nullptr); |
REPORTER_ASSERT(reporter, empty.size() == 0); |
// File in root dir |
@@ -99,7 +99,7 @@ DEF_TEST(OSPath, reporter) { |
filename.reset(); |
test_dir_with_file(reporter, dir, filename); |
- // Test that NULL can be used for the directory and filename. |
- SkString emptyPath = SkOSPath::Join(NULL, NULL); |
+ // Test that nullptr can be used for the directory and filename. |
+ SkString emptyPath = SkOSPath::Join(nullptr, nullptr); |
REPORTER_ASSERT(reporter, emptyPath.isEmpty()); |
} |